## Modules

::: pyeuclid.engine.engine

::: pyeuclid.engine.inference_rule

::: pyeuclid.engine.deductive_database

::: pyeuclid.engine.algebraic_system

::: pyeuclid.engine.proof_generator

::: pyeuclid.formalization.state

::: pyeuclid.formalization.relation

::: pyeuclid.formalization.translation

::: pyeuclid.formalization.diagram

::: pyeuclid.formalization.utils

